/*
 * Copyright 2002-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jdbc.datasource.init;

import org.springframework.core.io.support.EncodedResource;

/**
 * Thrown by {@link ScriptUtils} if an SQL script cannot be properly parsed.
 *
 * @author Sam Brannen
 * @since 4.0.3
 */
@SuppressWarnings("serial")
public class ScriptParseException extends ScriptException {

	/**
	 * Construct a new {@code ScriptParseException}.
	 * @param message detailed message
	 * @param resource the resource from which the SQL script was read
	 */
	public ScriptParseException(String message, EncodedResource resource) {
		super(buildMessage(message, resource));
	}

	/**
	 * Construct a new {@code ScriptParseException}.
	 * @param message detailed message
	 * @param resource the resource from which the SQL script was read
	 * @param cause the underlying cause of the failure
	 */
	public ScriptParseException(String message, EncodedResource resource, Throwable cause) {
		super(buildMessage(message, resource), cause);
	}

	private static String buildMessage(String message, EncodedResource resource) {
		return String.format("Failed to parse SQL script from resource [%s]: %s", (resource == null ? "<unknown>"
				: resource), message);
	}

}
